Module pmtiles2::util

source ·
Utilities for reading and writing PMTiles archives.

Structs

  • An error indicating that the specified tile id has a z value greater than the maximum allowed z value.
  • A structure representing a range of bytes within a larger amount of bytes.

Enums

  • Strategies to divide entries into one or multiple leaf directories, when root directory overflows maximum size.

Functions