Utilities for reading and writing PMTiles archives.
Structs
- An error indicating that the specified tile id has a z value greater than the maximum allowed z value.
- A structure representing a range of bytes within a larger amount of bytes.
Enums
- Strategies to divide entries into one or multiple leaf directories, when root directory overflows maximum size.
Functions
- Returns a new instance of
std::io::Writethat will emit compressed data to the underlying writer. - Compresses a byte slice and returns the result as a new
Vec<u8>. - compress_async
asyncAsync version ofcompress. - Returns a new instance of
std::io::Readthat will emit uncompressed data from an the underlying reader. - Decompresses a byte slice and returns the result as a new
Vec<u8>. - decompress_async
asyncAsync version ofdecompress. - Reads directories (root- & leaf-directories) from a reader and return all entries as a
std::collections::HashMap, with the tile-id as the key and the offset & length as the value. - Async version of
read_directories. - Converts z/x/y coordinates to a tile id.
- Writes root directory to a writer and return bytes of leaf directory section.
- Async version of
write_directories. - Converts a tile id to z/x/y coordinates.